==> haskell-wai-middleware-static-0.8.2-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-KTDFhH2obHYAR1cWjhVB9D
key: wai-middleware-static-0.8.2-KTDFhH2obHYAR1cWjhVB9D
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: 4277b9bea008d5187f0142d4fdda1319
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-KTDFhH2obHYAR1cWjhVB9D
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    cryptonite-0.25-HG1e5oKlC351RQKtUSxglv
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi directory-1.3.1.5
    expiring-cache-map-0.0.6.1-Dol3XOpYy8Y47YsAwWAdPB filepath-1.4.2
    http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl
    mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4 mtl-2.2.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0 time-1.8.0.2
    wai-3.2.1.2-2Zp08jZTTCf5NIL0VZMFx7
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-HG1e5oKlC351RQKtUSxglv=5008fcc70bd425af43dd504f7310f344
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ebd23a14864af42a4155f70cf1514d40
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             expiring-cache-map-0.0.6.1-Dol3XOpYy8Y47YsAwWAdPB=6f0c0339291d99d80ccce8b2062835c7
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl=f077e3c0d9d6c05be2dfc7d9c3ae67ad
             mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4=6bc38bc2f3d7f7e0258709c15024ed43
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             wai-3.2.1.2-2Zp08jZTTCf5NIL0VZMFx7=1b3b53b0d45a8d6668a7144a7e93d4f6
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.8.2-29-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-Jo2JK2H5q202laK7M3WH7z
key: wai-middleware-static-0.8.2-Jo2JK2H5q202laK7M3WH7z
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: f5577e7c049a2d6a38b3edb259fb8845
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-Jo2JK2H5q202laK7M3WH7z
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk directory-1.3.1.5
    expiring-cache-map-0.0.6.1-Dol3XOpYy8Y47YsAwWAdPB filepath-1.4.2
    http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4 mtl-2.2.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0 time-1.8.0.2
    wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             expiring-cache-map-0.0.6.1-Dol3XOpYy8Y47YsAwWAdPB=6f0c0339291d99d80ccce8b2062835c7
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=1f2d3d0537de744febdcb254f1bfc8b9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf=91ba5164ada377f7d55099a2359e2c5a
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
